Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(9)

Unified Diff: tools/SkBitmapRegionDecoderInterface.h

Issue 1402863002: Implementation of SkBitmapRegionDecoder using SkAndroidCodec (Closed) Base URL: https://skia.googlesource.com/skia.git@split1
Patch Set: Let's call this AndroidCodec_Strategy Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tools/SkBitmapRegionDecoderInterface.h
diff --git a/tools/SkBitmapRegionDecoderInterface.h b/tools/SkBitmapRegionDecoderInterface.h
index 047f023c808bd4a419befb5d98334e5990140ecd..8b15ad9986d2ce6e066f9944826fbfd49e5abe82 100644
--- a/tools/SkBitmapRegionDecoderInterface.h
+++ b/tools/SkBitmapRegionDecoderInterface.h
@@ -19,9 +19,9 @@ class SkBitmapRegionDecoderInterface {
public:
enum Strategy {
- kCanvas_Strategy, // Draw to the canvas, uses SkCodec
- kOriginal_Strategy, // Sampling, uses SkImageDecoder
- // TODO (msarett): Add strategy for SkScaledCodec
+ kCanvas_Strategy, // Draw to the canvas, uses SkCodec
+ kOriginal_Strategy, // Sampling, uses SkImageDecoder
+ kAndroidCodec_Strategy, // Uses SkAndroidCodec for scaling and subsetting
};
/*

Powered by Google App Engine
This is Rietveld 408576698